@@ -62,7 +62,6 @@ wxBitmap MyArtProvider::CreateBitmap(
 	return wxNullBitmap;
 }
 
-#include <mrpt/gui.h>
 #include <mrpt/nav.h>
 #include <mrpt/opengl.h>
 #include <mrpt/serialization/CArchive.h>
@@ -1085,7 +1084,7 @@ void reactive_navigator_demoframe::OnAbout(wxCommandEvent&)
 
 void reactive_navigator_demoframe::updateMap3DView()
 {
-	gl_grid = m_gridMap.getVisualization();
+	m_gridMap.getVisualizationInto(*gl_grid);
 }
 
 void reactive_navigator_demoframe::OnbtnPlaceRobotClick(wxCommandEvent& event)
