@@ -15,31 +15,37 @@
 //  Started: HL @ SEPT-2018
 // ===========================================================================
 
-#include <cv_bridge/cv_bridge.h>
+#include <cv_bridge/cv_bridge.h>  // this header is obsolete in ros2-I but as long as this app is only built for ros1 we are ok
 #include <mrpt/3rdparty/tclap/CmdLine.h>
 #include <mrpt/containers/yaml.h>
 #include <mrpt/io/CFileGZInputStream.h>
 #include <mrpt/io/CFileGZOutputStream.h>
 #include <mrpt/obs/CActionCollection.h>
 #include <mrpt/obs/CActionRobotMovement3D.h>
+#include <mrpt/obs/CObservation2DRangeScan.h>
 #include <mrpt/obs/CObservation3DRangeScan.h>
 #include <mrpt/obs/CObservationIMU.h>
+#include <mrpt/obs/CObservationOdometry.h>
 #include <mrpt/obs/CObservationPointCloud.h>
 #include <mrpt/obs/CObservationRotatingScan.h>
 #include <mrpt/poses/CPose3DQuat.h>
 #include <mrpt/ros1bridge/imu.h>
+#include <mrpt/ros1bridge/laser_scan.h>
 #include <mrpt/ros1bridge/point_cloud2.h>
+#include <mrpt/ros1bridge/pose.h>
 #include <mrpt/ros1bridge/time.h>
 #include <mrpt/serialization/CArchive.h>
 #include <mrpt/serialization/CSerializable.h>
 #include <mrpt/system/filesystem.h>
 #include <mrpt/system/os.h>
 #include <mrpt/system/progress.h>
+#include <nav_msgs/Odometry.h>
 #include <rosbag/bag.h>	 // rosbag_storage C++ lib
 #include <rosbag/view.h>
 #include <sensor_msgs/CameraInfo.h>
 #include <sensor_msgs/Image.h>
 #include <sensor_msgs/Imu.h>
+#include <sensor_msgs/LaserScan.h>
 #include <sensor_msgs/PointCloud2.h>
 #include <std_msgs/Int32.h>
 #include <tf2/buffer_core.h>
@@ -235,6 +241,22 @@ Obs toPointCloud2(std::string_view msg, const rosbag::MessageInstance& rosmsg)
 	return {ptsObs};
 }
 
+Obs toLidar2D(std::string_view msg, const rosbag::MessageInstance& rosmsg)
+{
+	auto scan = rosmsg.instantiate<sensor_msgs::LaserScan>();
+
+	auto scanObs = mrpt::obs::CObservation2DRangeScan::Create();
+
+	MRPT_TODO("Extract sensor pose from tf frames");
+	mrpt::poses::CPose3D sensorPose;
+	mrpt::ros1bridge::fromROS(*scan, sensorPose, *scanObs);
+
+	scanObs->sensorLabel = msg;
+	scanObs->timestamp = mrpt::ros1bridge::fromROS(scan->header.stamp);
+
+	return {scanObs};
+}
+
 Obs toRotatingScan(std::string_view msg, const rosbag::MessageInstance& rosmsg)
 {
 	auto pts = rosmsg.instantiate<sensor_msgs::PointCloud2>();
@@ -280,6 +302,27 @@ Obs toIMU(std::string_view msg, const rosbag::MessageInstance& rosmsg)
 	return {mrptObs};
 }
 
+Obs toOdometry(std::string_view msg, const rosbag::MessageInstance& rosmsg)
+{
+	auto odo = rosmsg.instantiate<nav_msgs::Odometry>();
+
+	auto mrptObs = mrpt::obs::CObservationOdometry::Create();
+
+	mrptObs->sensorLabel = msg;
+	mrptObs->timestamp = mrpt::ros1bridge::fromROS(odo->header.stamp);
+
+	// Convert data:
+	const auto pose = mrpt::ros1bridge::fromROS(odo->pose);
+	mrptObs->odometry = {pose.mean.x(), pose.mean.y(), pose.mean.yaw()};
+
+	mrptObs->hasVelocities = true;
+	mrptObs->velocityLocal.vx = odo->twist.twist.linear.x;
+	mrptObs->velocityLocal.vy = odo->twist.twist.linear.y;
+	mrptObs->velocityLocal.omega = odo->twist.twist.angular.z;
+
+	return {mrptObs};
+}
+
 Obs toRangeImage(
 	std::string_view msg, const sensor_msgs::Image::Ptr& image,
 	const sensor_msgs::CameraInfo::Ptr& cameraInfo, bool rangeIsDepth)
@@ -431,6 +474,15 @@ class Transcriber
 					callback);
 				// m_lookup["/tf"].emplace_back(sync->bindTfSync());
 			}
+			else if (sensorType == "CObservation2DRangeScan")
+			{
+				auto callback = [=](const rosbag::MessageInstance& m) {
+					return toLidar2D(sensorName, m);
+				};
+				m_lookup[sensor.at("topic").as<std::string>()].emplace_back(
+					callback);
+				// m_lookup["/tf"].emplace_back(sync->bindTfSync());
+			}
 			else if (sensorType == "CObservationRotatingScan")
 			{
 				auto callback = [=](const rosbag::MessageInstance& m) {
@@ -448,6 +500,14 @@ class Transcriber
 					callback);
 				// m_lookup["/tf"].emplace_back(sync->bindTfSync());
 			}
+			else if (sensorType == "CObservationOdometry")
+			{
+				auto callback = [=](const rosbag::MessageInstance& m) {
+					return toOdometry(sensorName, m);
+				};
+				m_lookup[sensor.at("topic").as<std::string>()].emplace_back(
+					callback);
+			}
 			// TODO: Handle more cases?
 		}
 	}
