@@ -14,7 +14,7 @@
 #endif
 #include <OpenNI.h>
 #include <PS1080.h>
-#include <mrpt/gui.h>
+#include <mrpt/gui/CDisplayWindow3D.h>
 #include <mrpt/maps/CColouredPointsMap.h>
 #include <mrpt/opengl.h>
 
@@ -160,7 +160,7 @@ int main(int argc, char** argv)
 	//										Create scene
 	//========================================================================================
 	gui::CDisplayWindow3D window;
-	opengl::COpenGLScene::Ptr scene;
+	opengl::Scene::Ptr scene;
 	mrpt::global_settings::OCTREE_RENDER_MAX_POINTS_PER_NODE(1000000);
 	window.setWindowTitle("RGB-D camera frame");
 	window.resize(800, 600);
