@@ -12,7 +12,6 @@
 #include <mrpt/3rdparty/tclap/CmdLine.h>
 #include <mrpt/apps/CGridMapAlignerApp.h>
 #include <mrpt/config/CConfigFile.h>
-#include <mrpt/gui.h>
 #include <mrpt/io/CFileGZInputStream.h>
 #include <mrpt/io/CFileGZOutputStream.h>
 #include <mrpt/io/CFileOutputStream.h>
@@ -26,6 +25,7 @@
 #include <mrpt/obs/CSensoryFrame.h>
 #include <mrpt/opengl/CGridPlaneXY.h>
 #include <mrpt/opengl/CSetOfLines.h>
+#include <mrpt/opengl/Scene.h>
 #include <mrpt/poses/CPoint2D.h>
 #include <mrpt/poses/CPosePDFGaussian.h>
 #include <mrpt/poses/CPosePDFParticles.h>
@@ -219,7 +219,6 @@ void CGridMapAlignerApp::run()
 	using namespace mrpt::math;
 	using namespace mrpt::serialization;
 	using namespace mrpt::config;
-	using namespace mrpt::gui;
 	using namespace mrpt::img;
 	using namespace mrpt::io;
 	using namespace mrpt::random;
@@ -556,7 +555,7 @@ void CGridMapAlignerApp::run()
 
 					if (SAVE_SOG_3DSCENE)
 					{
-						COpenGLScene scene3D;
+						Scene scene3D;
 						opengl::CSetOfObjects::Ptr thePDF3D =
 							std::make_shared<opengl::CSetOfObjects>();
 						pdf_SOG->getAs3DObject(thePDF3D);
@@ -642,7 +641,7 @@ void CGridMapAlignerApp::run()
 								RESULTS_DIR.c_str(), (unsigned int)nNode));
 
 							// Save as 3D scene:
-							COpenGLScene scene;
+							Scene scene;
 							auto obj1 = the_map1.getVisualization();
 							auto obj2 = the_map2.getVisualization();
 							obj2->setPose(x);
