@@ -17,8 +17,8 @@
 #include <mrpt/maps/COccupancyGridMap2D.h>
 #include <mrpt/obs/CObservationOdometry.h>
 #include <mrpt/opengl/CGridPlaneXY.h>
-#include <mrpt/opengl/COpenGLScene.h>
 #include <mrpt/opengl/CPlanarLaserScan.h>  // from lib [mrpt-maps]
+#include <mrpt/opengl/Scene.h>
 #include <mrpt/opengl/stock_objects.h>
 #include <mrpt/serialization/CArchive.h>
 #include <mrpt/slam/CMetricMapBuilderICP.h>
@@ -273,7 +273,7 @@ void ICP_SLAM_App_Base::run()
 		f_log.printf(
 			"%f %i\n", 1000.0f * t_exec, mapBuilder.getCurrentlyBuiltMapSize());
 
-		const CMultiMetricMap* mostLikMap =
+		const CMultiMetricMap& mostLikMap =
 			mapBuilder.getCurrentlyBuiltMetricMap();
 
 		if (LOG_FREQUENCY > 0 && 0 == (step % LOG_FREQUENCY))
@@ -297,12 +297,12 @@ void ICP_SLAM_App_Base::run()
 		if ((LOG_FREQUENCY > 0 && 0 == (step % LOG_FREQUENCY)) ||
 			(SAVE_3D_SCENE || win3D))
 		{
-			auto scene = mrpt::opengl::COpenGLScene::Create();
+			auto scene = mrpt::opengl::Scene::Create();
 
-			COpenGLViewport::Ptr view = scene->getViewport("main");
+			Viewport::Ptr view = scene->getViewport("main");
 			ASSERT_(view);
 
-			COpenGLViewport::Ptr view_map = scene->createViewport("mini-map");
+			Viewport::Ptr view_map = scene->createViewport("mini-map");
 			view_map->setBorderSize(2);
 			view_map->setViewportPosition(0.01, 0.01, 0.35, 0.35);
 			view_map->setTransparent(false);
@@ -335,10 +335,10 @@ void ICP_SLAM_App_Base::run()
 			}
 
 			// The maps:
-			view->insert(mostLikMap->getVisualization());
+			view->insert(mostLikMap.getVisualization());
 
 			// Only the point map:
-			if (auto pMap = mostLikMap->mapByClass<CPointsMap>(); pMap)
+			if (auto pMap = mostLikMap.mapByClass<CPointsMap>(); pMap)
 				view_map->insert(pMap->getVisualization());
 
 			// Draw the robot path:
@@ -381,8 +381,7 @@ void ICP_SLAM_App_Base::run()
 			// Show 3D?
 			if (win3D)
 			{
-				opengl::COpenGLScene::Ptr& ptrScene =
-					win3D->get3DSceneAndLock();
+				opengl::Scene::Ptr& ptrScene = win3D->get3DSceneAndLock();
 				ptrScene = scene;
 
 				win3D->unlockAccess3DScene();
@@ -445,11 +444,11 @@ void ICP_SLAM_App_Base::run()
 	}
 
 	{
-		const CMultiMetricMap* finalPointsMap =
+		const CMultiMetricMap& finalPointsMap =
 			mapBuilder.getCurrentlyBuiltMetricMap();
 		auto str = format("%s/_finalmaps_.txt", OUT_DIR);
 		MRPT_LOG_INFO_FMT("Dumping final metric maps to %s_XXX\n", str.c_str());
-		finalPointsMap->saveMetricMapRepresentationToFile(str);
+		finalPointsMap.saveMetricMapRepresentationToFile(str);
 	}
 
 	if (win3D) win3D->waitForKey();
@@ -612,13 +611,12 @@ void ICP_SLAM_App_Live::SensorThread(ICP_SLAM_App_Live::TThreadParams tp)
 		{
 			sensor->doProcess();  // Process
 			// Get new observations
-			CGenericSensor::TListObservations lstObjs;
-			sensor->getObservations(lstObjs);
+			const CGenericSensor::TListObservations lstObjs =
+				sensor->getObservations();
 			{
 				std::lock_guard<std::mutex> lock(m_cs_global_list_obs);
 				m_global_list_obs.insert(lstObjs.begin(), lstObjs.end());
 			}
-			lstObjs.clear();
 
 			// wait for the process period:
 			rate.sleep();
