@@ -402,10 +402,10 @@ void RBPF_SLAM_App_Base::run()
 			}
 
 			// Save a 3D scene view of the mapping process:
-			COpenGLScene::Ptr scene;
+			Scene::Ptr scene;
 			if (SAVE_3D_SCENE || SHOW_PROGRESS_IN_WINDOW)
 			{
-				scene = std::make_shared<COpenGLScene>();
+				scene = std::make_shared<Scene>();
 
 				// The ground:
 				mrpt::opengl::CGridPlaneXY::Ptr groundPlane =
@@ -509,7 +509,7 @@ void RBPF_SLAM_App_Base::run()
 
 			if (SHOW_PROGRESS_IN_WINDOW)
 			{
-				COpenGLScene::Ptr& scenePtr = win3D->get3DSceneAndLock();
+				Scene::Ptr& scenePtr = win3D->get3DSceneAndLock();
 				scenePtr = scene;
 				win3D->unlockAccess3DScene();
 
@@ -628,6 +628,15 @@ RBPF_SLAM_App_Rawlog::RBPF_SLAM_App_Rawlog()
 	setLoggerName("RBPF_SLAM_App_Rawlog");
 }
 
+void RBPF_SLAM_App_Rawlog::init(
+	const std::string& iniConfigFile, const std::string& rawlogFile)
+{
+	const int argc = 3;
+	const char* argv[3] = {
+		"rbpf-slam", iniConfigFile.c_str(), rawlogFile.c_str()};
+	initialize(argc, argv);
+}
+
 void RBPF_SLAM_App_Rawlog::impl_initialize(int argc, const char** argv)
 {
 	MRPT_START
