@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2022, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2023, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -419,8 +419,14 @@ void CInterfaceFTDI::Purge()
 	auto* ctx = static_cast<ftdi_context*>(m_ftdi_context);
 	ASSERT_(ctx->usb_dev);
 
+#if MRPT_FTDI_VERSION >= 0x150
+	if (ftdi_tcioflush(ctx) < 0)
+#else
 	if (ftdi_usb_purge_buffers(ctx) < 0)
+#endif
+	{
 		THROW_EXCEPTION("Error purging device buffers");
+	}
 
 	m_readBuffer.clear();
 #endif
