@@ -361,7 +361,7 @@ void CICPCriteriaERD<GRAPH_T>::toggleLaserScansVisualization()
 	this->logFmt(
 		mrpt::system::LVL_INFO, "Toggling LaserScans visualization...");
 
-	COpenGLScene::Ptr scene = this->m_win->get3DSceneAndLock();
+	Scene::Ptr scene = this->m_win->get3DSceneAndLock();
 
 	if (params.visualize_laser_scans)
 	{
@@ -408,7 +408,7 @@ void CICPCriteriaERD<GRAPH_T>::initializeVisuals()
 	// ICP_max_distance disk
 	if (params.ICP_max_distance > 0)
 	{
-		COpenGLScene::Ptr scene = this->m_win->get3DSceneAndLock();
+		Scene::Ptr scene = this->m_win->get3DSceneAndLock();
 
 		CDisk::Ptr obj = std::make_shared<CDisk>();
 		pose_t initial_pose;
@@ -426,7 +426,7 @@ void CICPCriteriaERD<GRAPH_T>::initializeVisuals()
 	// laser scan visualization
 	if (params.visualize_laser_scans)
 	{
-		COpenGLScene::Ptr scene = this->m_win->get3DSceneAndLock();
+		Scene::Ptr scene = this->m_win->get3DSceneAndLock();
 
 		CPlanarLaserScan::Ptr laser_scan_viz =
 			mrpt::opengl::CPlanarLaserScan::Create();
@@ -472,7 +472,7 @@ void CICPCriteriaERD<GRAPH_T>::updateVisuals()
 	// update ICP_max_distance Disk
 	if (this->m_win && params.ICP_max_distance > 0)
 	{
-		COpenGLScene::Ptr scene = this->m_win->get3DSceneAndLock();
+		Scene::Ptr scene = this->m_win->get3DSceneAndLock();
 
 		CRenderizable::Ptr obj = scene->getByName("ICP_max_distance");
 		CDisk::Ptr disk_obj = std::dynamic_pointer_cast<CDisk>(obj);
@@ -487,7 +487,7 @@ void CICPCriteriaERD<GRAPH_T>::updateVisuals()
 	if (this->m_win && params.visualize_laser_scans &&
 		(m_last_laser_scan2D || m_fake_laser_scan2D))
 	{
-		COpenGLScene::Ptr scene = this->m_win->get3DSceneAndLock();
+		Scene::Ptr scene = this->m_win->get3DSceneAndLock();
 
 		CRenderizable::Ptr obj = scene->getByName("laser_scan_viz");
 		CPlanarLaserScan::Ptr laser_scan_viz =
@@ -507,15 +507,12 @@ void CICPCriteriaERD<GRAPH_T>::updateVisuals()
 		auto search = this->m_graph->nodes.find(this->m_graph->nodeCount() - 1);
 		if (search != this->m_graph->nodes.end())
 		{
-			laser_scan_viz->setPose(
-				this->m_graph->nodes[this->m_graph->nodeCount() - 1]);
+			auto p = mrpt::math::TPose3D(
+				this->m_graph->nodes[this->m_graph->nodeCount() - 1].asTPose());
 			// put the laser scan *underneath* the graph, so that you can still
 			// visualize the loop closures with the nodes ahead
-			laser_scan_viz->setPose(CPose3D(
-				laser_scan_viz->getPoseX(), laser_scan_viz->getPoseY(), -0.15,
-				DEG2RAD(laser_scan_viz->getPoseYaw()),
-				DEG2RAD(laser_scan_viz->getPosePitch()),
-				DEG2RAD(laser_scan_viz->getPoseRoll())));
+			p.z = -0.15;
+			laser_scan_viz->setPose(p);
 		}
 
 		this->m_win->unlockAccess3DScene();
