@@ -12,7 +12,7 @@
 // Implementation file for CWindowObserver class
 #include <mrpt/graphslam/misc/CWindowObserver.h>
 #include <mrpt/gui/CBaseGUIWindow.h>
-#include <mrpt/opengl/COpenGLViewport.h>
+#include <mrpt/opengl/Viewport.h>
 
 using namespace mrpt::graphslam;
 
@@ -128,7 +128,7 @@ void CWindowObserver::OnEvent(const mrpt::system::mrptEvent& e)
 	else if (e.isOfType<mrpt::opengl::mrptEventGLPostRender>())
 	{
 		/*
-		 * An event sent by an mrpt::opengl::COpenGLViewport AFTER calling
+		 * An event sent by an mrpt::opengl::Viewport AFTER calling
 		 * the
 		 * SCENE OPENGL DRAWING PRIMITIVES and before doing a glSwapBuffers.
 		 */
