@@ -11,7 +11,7 @@
 
 #include <mrpt/config.h>
 #include <mrpt/gui/CGlCanvasBase.h>
-#include <mrpt/opengl/COpenGLScene.h>
+#include <mrpt/opengl/Scene.h>
 #include <mrpt/opengl/opengl_fonts.h>
 
 #include <atomic>
