@@ -17,6 +17,9 @@
 #include <mrpt/config.h>
 #if MRPT_HAS_NANOGUI
 
+#ifdef None	 // X11 headers conflict...
+#undef None
+#endif
 #include <nanogui/nanogui.h>
 
 namespace mrpt::gui
@@ -40,7 +43,7 @@ class MRPT2NanoguiGLCanvas : public nanogui::GLCanvas
 	/** The scene to render in this control.
 	 * \note Users must lock the mutex scene_mtx while modifying this variable.
 	 */
-	mrpt::opengl::COpenGLScene::Ptr scene;
+	mrpt::opengl::Scene::Ptr scene;
 	std::mutex scene_mtx;
 
 	CGlCanvasBase& camera() { return m_headless_canvas; }
