@@ -68,7 +68,7 @@ class CColouredPointsMap : public CPointsMap
 	 * \sa getPointAllFields, setPointAllFields, setPointAllFieldsFast
 	 */
 	void getPointAllFieldsFast(
-		const size_t index, std::vector<float>& point_data) const override
+		size_t index, std::vector<float>& point_data) const override
 	{
 		point_data.resize(6);
 		point_data[0] = m_x[index];
@@ -85,7 +85,7 @@ class CColouredPointsMap : public CPointsMap
 	 * \sa setPointAllFields, getPointAllFields, getPointAllFieldsFast
 	 */
 	void setPointAllFieldsFast(
-		const size_t index, const std::vector<float>& point_data) override
+		size_t index, const std::vector<float>& point_data) override
 	{
 		ASSERTDEB_(point_data.size() == 6);
 		m_x[index] = point_data[0];
@@ -110,7 +110,7 @@ class CColouredPointsMap : public CPointsMap
    protected:
 	void impl_copyFrom(const CPointsMap& obj) override;
 	void addFrom_classSpecific(
-		const CPointsMap& anotherMap, const size_t nPreviousPoints,
+		const CPointsMap& anotherMap, size_t nPreviousPoints,
 		const bool filterOutPointsAtZero) override;
 
 	// Friend methods:
@@ -331,18 +331,18 @@ class CColouredPointsMap : public CPointsMap
 	 * color info.
 	 */
 	void PLY_import_set_vertex(
-		const size_t idx, const mrpt::math::TPoint3Df& pt,
+		size_t idx, const mrpt::math::TPoint3Df& pt,
 		const mrpt::img::TColorf* pt_color = nullptr) override;
 
 	/** In a base class, reserve memory to prepare subsequent calls to
 	 * PLY_import_set_vertex */
-	void PLY_import_set_vertex_count(const size_t N) override;
+	void PLY_import_set_vertex_count(size_t N) override;
 	/** @} */
 
 	/** @name Redefinition of PLY Export virtual methods from CPointsMap
 		@{ */
 	void PLY_export_get_vertex(
-		const size_t idx, mrpt::math::TPoint3Df& pt, bool& pt_has_color,
+		size_t idx, mrpt::math::TPoint3Df& pt, bool& pt_has_color,
 		mrpt::img::TColorf& pt_color) const override;
 	/** @} */
 
@@ -397,7 +397,7 @@ class PointCloudAdapter<mrpt::maps::CColouredPointsMap>
 	}
 	/** Set XYZ coordinates of i'th point */
 	inline void setPointXYZ(
-		const size_t idx, const coords_t x, const coords_t y, const coords_t z)
+		size_t idx, const coords_t x, const coords_t y, const coords_t z)
 	{
 		m_obj.setPointFast(idx, x, y, z);
 	}
@@ -405,7 +405,7 @@ class PointCloudAdapter<mrpt::maps::CColouredPointsMap>
 	/** Get XYZ_RGBf coordinates of i'th point */
 	template <typename T>
 	inline void getPointXYZ_RGBAf(
-		const size_t idx, T& x, T& y, T& z, float& r, float& g, float& b,
+		size_t idx, T& x, T& y, T& z, float& r, float& g, float& b,
 		float& a) const
 	{
 		m_obj.getPointRGB(idx, x, y, z, r, g, b);
@@ -413,7 +413,7 @@ class PointCloudAdapter<mrpt::maps::CColouredPointsMap>
 	}
 	/** Set XYZ_RGBf coordinates of i'th point */
 	inline void setPointXYZ_RGBAf(
-		const size_t idx, const coords_t x, const coords_t y, const coords_t z,
+		size_t idx, const coords_t x, const coords_t y, const coords_t z,
 		const float r, const float g, const float b,
 		[[maybe_unused]] const float a)
 	{
@@ -423,8 +423,7 @@ class PointCloudAdapter<mrpt::maps::CColouredPointsMap>
 	/** Get XYZ_RGBu8 coordinates of i'th point */
 	template <typename T>
 	inline void getPointXYZ_RGBu8(
-		const size_t idx, T& x, T& y, T& z, uint8_t& r, uint8_t& g,
-		uint8_t& b) const
+		size_t idx, T& x, T& y, T& z, uint8_t& r, uint8_t& g, uint8_t& b) const
 	{
 		float Rf, Gf, Bf;
 		m_obj.getPointRGB(idx, x, y, z, Rf, Gf, Bf);
@@ -434,28 +433,27 @@ class PointCloudAdapter<mrpt::maps::CColouredPointsMap>
 	}
 	/** Set XYZ_RGBu8 coordinates of i'th point */
 	inline void setPointXYZ_RGBu8(
-		const size_t idx, const coords_t x, const coords_t y, const coords_t z,
+		size_t idx, const coords_t x, const coords_t y, const coords_t z,
 		const uint8_t r, const uint8_t g, const uint8_t b)
 	{
 		m_obj.setPointRGB(idx, x, y, z, r / 255.f, g / 255.f, b / 255.f);
 	}
 
 	/** Get RGBf color of i'th point */
-	inline void getPointRGBf(
-		const size_t idx, float& r, float& g, float& b) const
+	inline void getPointRGBf(size_t idx, float& r, float& g, float& b) const
 	{
 		m_obj.getPointColor_fast(idx, r, g, b);
 	}
 	/** Set XYZ_RGBf coordinates of i'th point */
 	inline void setPointRGBf(
-		const size_t idx, const float r, const float g, const float b)
+		size_t idx, const float r, const float g, const float b)
 	{
 		m_obj.setPointColor_fast(idx, r, g, b);
 	}
 
 	/** Get RGBu8 color of i'th point */
 	inline void getPointRGBu8(
-		const size_t idx, uint8_t& r, uint8_t& g, uint8_t& b) const
+		size_t idx, uint8_t& r, uint8_t& g, uint8_t& b) const
 	{
 		float R, G, B;
 		m_obj.getPointColor_fast(idx, R, G, B);
@@ -465,13 +463,13 @@ class PointCloudAdapter<mrpt::maps::CColouredPointsMap>
 	}
 	/** Set RGBu8 coordinates of i'th point */
 	inline void setPointRGBu8(
-		const size_t idx, const uint8_t r, const uint8_t g, const uint8_t b)
+		size_t idx, const uint8_t r, const uint8_t g, const uint8_t b)
 	{
 		m_obj.setPointColor_fast(idx, r / 255.f, g / 255.f, b / 255.f);
 	}
 
 	/** Set XYZ coordinates of i'th point */
-	inline void setInvalidPoint(const size_t idx)
+	inline void setInvalidPoint(size_t idx)
 	{
 		m_obj.setPointFast(idx, 0, 0, 0);
 	}
