@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2022, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2023, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -74,8 +74,7 @@ class CHeightGridMap2D_MRF : public CRandomFieldGridMap2D,
 	double dem_get_resolution() const override;
 	size_t dem_get_size_x() const override;
 	size_t dem_get_size_y() const override;
-	bool dem_get_z_by_cell(
-		const size_t cx, const size_t cy, double& z_out) const override;
+	bool dem_get_z_by_cell(size_t cx, size_t cy, double& z_out) const override;
 	bool dem_get_z(
 		const double x, const double y, double& z_out) const override;
 	void dem_update_map() override;
