@@ -39,7 +39,7 @@ void ransac_detect_3D_planes(
 	const CVectorDynamic<NUMTYPE>& x, const CVectorDynamic<NUMTYPE>& y,
 	const CVectorDynamic<NUMTYPE>& z,
 	std::vector<std::pair<size_t, TPlane>>& out_detected_planes,
-	const double threshold, const size_t min_inliers_for_valid_plane = 10);
+	const double threshold, size_t min_inliers_for_valid_plane = 10);
 
 /** Fit a number of 2-D lines to a given point cloud, automatically determining
  * the number of existing lines by means of the provided threshold and minimum
@@ -55,7 +55,7 @@ template <typename NUMTYPE>
 void ransac_detect_2D_lines(
 	const CVectorDynamic<NUMTYPE>& x, const CVectorDynamic<NUMTYPE>& y,
 	std::vector<std::pair<size_t, TLine2D>>& out_detected_lines,
-	const double threshold, const size_t min_inliers_for_valid_line = 5);
+	const double threshold, size_t min_inliers_for_valid_line = 5);
 
 /** A stub for ransac_detect_3D_planes() with the points given as a
  * mrpt::maps::CPointsMap
@@ -64,7 +64,7 @@ template <class POINTSMAP>
 inline void ransac_detect_3D_planes(
 	const POINTSMAP* points_map,
 	std::vector<std::pair<size_t, TPlane>>& out_detected_planes,
-	const double threshold, const size_t min_inliers_for_valid_plane)
+	const double threshold, size_t min_inliers_for_valid_plane)
 {
 	CVectorFloat xs, ys, zs;
 	points_map->getAllPoints(xs, ys, zs);
