@@ -218,7 +218,7 @@ bool CReactiveNavigationSystem::implementSenseObstacles(
 
 /** \callergraph */
 void CReactiveNavigationSystem::STEP3_WSpaceToTPSpace(
-	const size_t ptg_idx, std::vector<double>& out_TPObstacles,
+	size_t ptg_idx, std::vector<double>& out_TPObstacles,
 	mrpt::nav::ClearanceDiagram& out_clearance,
 	const mrpt::math::TPose2D& rel_pose_PTG_origin_wrt_sense_,
 	const bool eval_clearance)
