@@ -25,8 +25,6 @@
 #include <mrpt/opengl/CMesh.h>
 #include <mrpt/opengl/CMesh3D.h>
 #include <mrpt/opengl/CMeshFast.h>
-#include <mrpt/opengl/COpenGLScene.h>
-#include <mrpt/opengl/COpenGLViewport.h>
 #include <mrpt/opengl/CPointCloud.h>
 #include <mrpt/opengl/CPointCloudColoured.h>
 #include <mrpt/opengl/CRenderizable.h>
@@ -39,10 +37,18 @@
 #include <mrpt/opengl/CText.h>
 #include <mrpt/opengl/CText3D.h>
 #include <mrpt/opengl/CTexturedPlane.h>
-//#include <mrpt/opengl/CPlanarLaserScan.h>			// It's in the lib mrpt-maps
-// now
-//#include <mrpt/opengl/CAngularObservationMesh.h>	// It's in the lib mrpt-maps
-// now
+#include <mrpt/opengl/Scene.h>
+#include <mrpt/opengl/Viewport.h>
+
+// These two are for easy backwards compatibility (MRPT <2.7.0)
+#include <mrpt/opengl/COpenGLScene.h>
+#include <mrpt/opengl/COpenGLViewport.h>
+
+// #include <mrpt/opengl/CPlanarLaserScan.h>			// It's in the lib
+// mrpt-maps
+//  now
+// #include <mrpt/opengl/CAngularObservationMesh.h>	// It's in the lib mrpt-maps
+//  now
 #include <mrpt/opengl/CCylinder.h>
 #include <mrpt/opengl/CEllipsoidInverseDepth2D.h>
 #include <mrpt/opengl/CEllipsoidInverseDepth3D.h>
@@ -50,6 +56,7 @@
 #include <mrpt/opengl/CFBORender.h>
 #include <mrpt/opengl/COctoMapVoxels.h>
 #include <mrpt/opengl/CPolyhedron.h>
+#include <mrpt/opengl/CSkyBox.h>
 #include <mrpt/opengl/CVectorField2D.h>
 #include <mrpt/opengl/CVectorField3D.h>
 #include <mrpt/opengl/graph_tools.h>
