@@ -29,8 +29,8 @@ class CMesh;
 class CMesh3D;
 class CMeshFast;
 class COctoMapVoxels;
-class COpenGLScene;
-class COpenGLViewport;
+class Scene;
+class Viewport;
 class CPointCloud;
 class CPointCloudColoured;
 class CPolyhedron;
