@@ -11,13 +11,11 @@
 //
 #include <mrpt/core/get_env.h>
 #include <mrpt/opengl/CFBORender.h>
+#include <mrpt/opengl/OpenGLDepth2LinearLUTs.h>
 #include <mrpt/opengl/opengl_api.h>
 //
 #include <mrpt/config.h>
 
-#include <mutex>
-#include <unordered_map>
-
 #define FBO_USE_LUT
 //#define FBO_PROFILER
 
@@ -43,60 +41,6 @@ const thread_local bool MRPT_FBORENDER_SHOW_DEVICES =
 const thread_local bool MRPT_FBORENDER_USE_LUT =
 	mrpt::get_env<bool>("MRPT_FBORENDER_USE_LUT", true);
 
-class OpenGLDepth2Linear_LUTs
-{
-   public:
-	constexpr static std::size_t NUM_ENTRIES = 1 << 18;
-
-	static OpenGLDepth2Linear_LUTs& Instance()
-	{
-		thread_local OpenGLDepth2Linear_LUTs lut;
-		return lut;
-	}
-
-	using lut_t = std::vector<float>;
-
-	lut_t& lut_from_zn_zf(float zn, float zf)
-	{
-		const auto p = std::pair<float, float>(zn, zf);
-		// reuse?
-		if (auto it = m_pool.find(p); it != m_pool.end()) return it->second;
-
-		// create new:
-		auto& lut = m_pool[p];
-		lut.resize(NUM_ENTRIES);
-
-		const auto linearDepth = [zn, zf](float depthSample) -> float {
-			if (depthSample == 1.0f) return 0.0f;  // no echo
-
-			depthSample = 2.0f * depthSample - 1.0f;
-			float zLinear =
-				2.0f * zn * zf / (zf + zn - depthSample * (zf - zn));
-			return zLinear;
-		};
-
-		for (size_t i = 0; i < NUM_ENTRIES; i++)
-		{
-			float f = -1.0f + 2.0f * static_cast<float>(i) / (NUM_ENTRIES - 1);
-			lut.at(i) = linearDepth(f);
-		}
-
-		return lut;
-	}
-
-   private:
-	struct MyHash
-	{
-		template <typename T>
-		std::size_t operator()(const std::pair<T, T>& x) const
-		{
-			return std::hash<T>()(x.first) ^ std::hash<T>()(x.second);
-		}
-	};
-
-	std::unordered_map<std::pair<float, float>, lut_t, MyHash> m_pool;
-};
-
 CFBORender::CFBORender(const Parameters& p) : m_params(p)
 {
 #if HAVE_FBO
@@ -267,7 +211,7 @@ CFBORender::CFBORender(const Parameters& p) : m_params(p)
 	CHECK_OPENGL_ERROR();
 
 	// unbind:
-	COpenGLFramebuffer::Bind(oldFB);
+	FrameBuffer::Bind(oldFB);
 
 	MRPT_END
 #else
@@ -288,7 +232,7 @@ CFBORender::~CFBORender()
 }
 
 void CFBORender::internal_render_RGBD(
-	[[maybe_unused]] const COpenGLScene& scene,
+	[[maybe_unused]] const Scene& scene,
 	[[maybe_unused]] const mrpt::optional_ref<mrpt::img::CImage>& optoutRGB,
 	[[maybe_unused]] const mrpt::optional_ref<mrpt::math::CMatrixFloat>&
 		optoutDepth)
@@ -312,13 +256,9 @@ void CFBORender::internal_render_RGBD(
 
 	const auto oldFBs = m_fb.bind();
 
-	// Get former viewport
-	GLint oldViewport[4];
-	glGetIntegerv(GL_VIEWPORT, oldViewport);
-
 	// change viewport size (in pixels)
-	glViewport(0, 0, m_fb.width(), m_fb.height());
-	CHECK_OPENGL_ERROR_IN_DEBUG();
+	// glViewport(0, 0, m_fb.width(), m_fb.height());
+	// CHECK_OPENGL_ERROR_IN_DEBUG();
 
 	// bind the framebuffer, fbo, so operations will now occur on it
 	glBindTexture(GL_TEXTURE_2D, m_texRGB);
@@ -404,57 +344,70 @@ void CFBORender::internal_render_RGBD(
 		tle1.stop();
 #endif
 
-		// Transform from OpenGL clip depths into linear distances:
-		const auto mats = scene.getViewport()->getRenderMatrices();
-		const float zn = mats.getLastClipZNear();
-		const float zf = mats.getLastClipZFar();
+		using depth_lut_t = OpenGLDepth2LinearLUTs<18>;
 
-		const OpenGLDepth2Linear_LUTs::lut_t* lut = nullptr;
+		// Dont create LUT if we are not about to use it anyway:
+		if (!m_params.raw_depth)
+		{
+			// Transform from OpenGL clip depths into linear distances:
+			const auto mats = scene.getViewport()->getRenderMatrices();
+			const float zn = mats.getLastClipZNear();
+			const float zf = mats.getLastClipZFar();
+
+			const depth_lut_t::lut_t* lut = nullptr;
 
 #if !defined(FBO_USE_LUT)
-		const bool do_use_lut = false;
+			const bool do_use_lut = false;
 #else
-		bool do_use_lut = MRPT_FBORENDER_USE_LUT;
-		// dont use LUT for really small image areas:
-		if (m_fb.height() * m_fb.width() < 10000) { do_use_lut = false; }
+			bool do_use_lut = MRPT_FBORENDER_USE_LUT;
+			// dont use LUT for really small image areas:
+			if (m_fb.height() * m_fb.width() < 10000) { do_use_lut = false; }
 #endif
 
-		if (do_use_lut)
-			lut = &OpenGLDepth2Linear_LUTs::Instance().lut_from_zn_zf(zn, zf);
+			if (do_use_lut)
+			{
+#ifdef FBO_PROFILER
+				auto tle_lut = mrpt::system::CTimeLoggerEntry(
+					profiler, sSec + ".get_lut"s);
+#endif
+				lut = &depth_lut_t::Instance().lut_from_zn_zf(zn, zf);
+			}
 
 #ifdef FBO_PROFILER
-		auto tle2 = mrpt::system::CTimeLoggerEntry(profiler, sSec + ".linear"s);
+			auto tle2 =
+				mrpt::system::CTimeLoggerEntry(profiler, sSec + ".linear"s);
 #endif
 
-		if (!do_use_lut)
-		{
-			// Depth buffer -> linear depth:
-			const auto linearDepth = [zn, zf](float depthSample) -> float {
-				depthSample = 2.0 * depthSample - 1.0;
-				float zLinear =
-					2.0 * zn * zf / (zf + zn - depthSample * (zf - zn));
-				return zLinear;
-			};
-			for (auto& d : outDepth)
+			if (!do_use_lut)
 			{
-				if (d == 1) d = 0;	// no "echo return"
-				else
-					d = linearDepth(d);
+				// Depth buffer -> linear depth:
+				const auto linearDepth = [zn, zf](float depthSample) -> float {
+					depthSample = 2.0 * depthSample - 1.0;
+					float zLinear =
+						2.0 * zn * zf / (zf + zn - depthSample * (zf - zn));
+					return zLinear;
+				};
+				for (auto& d : outDepth)
+				{
+					if (d == 1) d = 0;	// no "echo return"
+					else
+						d = linearDepth(d);
+				}
 			}
-		}
-		else
-		{
-			// map d in [-1.0f,+1.0f] ==> real depth values:
-			for (auto& d : outDepth)
+			else
 			{
-				d = (*lut)
-					[(d + 1.0f) * (OpenGLDepth2Linear_LUTs::NUM_ENTRIES - 1) /
-					 2];
+				// map d in [-1.0f,+1.0f] ==> real depth values:
+				for (auto& d : outDepth)
+				{
+					d = (*lut)[(d + 1.0f) * (depth_lut_t::NUM_ENTRIES - 1) / 2];
+				}
 			}
+#ifdef FBO_PROFILER
+			tle2.stop();
+#endif
 		}
 
 #ifdef FBO_PROFILER
-		tle2.stop();
 		auto tle3 = mrpt::system::CTimeLoggerEntry(profiler, sSec + ".flip"s);
 #endif
 
@@ -475,28 +428,25 @@ void CFBORender::internal_render_RGBD(
 
 	//'unbind' the frambuffer object, so subsequent drawing ops are not
 	// drawn into the FBO.
-	COpenGLFramebuffer::Bind(oldFBs);
-
-	// Restore viewport:
-	glViewport(oldViewport[0], oldViewport[1], oldViewport[2], oldViewport[3]);
+	FrameBuffer::Bind(oldFBs);
 
 	MRPT_END
 #endif
 }
 
-void CFBORender::render_RGB(const COpenGLScene& scene, CImage& outRGB)
+void CFBORender::render_RGB(const Scene& scene, CImage& outRGB)
 {
 	internal_render_RGBD(scene, outRGB, std::nullopt);
 }
 
 void CFBORender::render_RGBD(
-	const COpenGLScene& scene, mrpt::img::CImage& outRGB,
+	const Scene& scene, mrpt::img::CImage& outRGB,
 	mrpt::math::CMatrixFloat& outDepth)
 {
 	internal_render_RGBD(scene, outRGB, outDepth);
 }
 void CFBORender::render_depth(
-	const COpenGLScene& scene, mrpt::math::CMatrixFloat& outDepth)
+	const Scene& scene, mrpt::math::CMatrixFloat& outDepth)
 {
 	internal_render_RGBD(scene, std::nullopt, outDepth);
 }
