@@ -118,6 +118,8 @@ void CPointCloud::onUpdateBuffers_Points()
 	// "CRenderizableShaderPoints::m_vertex_buffer_data" is already done, since
 	// "m_points" is an alias for it.
 
+	const auto myColor = getColor_u8();
+
 	// color buffer:
 	auto& cbd = CRenderizableShaderPoints::m_color_buffer_data;
 	cbd.clear();
@@ -141,13 +143,13 @@ void CPointCloud::onUpdateBuffers_Points()
 				{f2u8(m_colorFromDepth_min.R + f * m_col_slop_inv.R),
 				 f2u8(m_colorFromDepth_min.G + f * m_col_slop_inv.G),
 				 f2u8(m_colorFromDepth_min.B + f * m_col_slop_inv.B),
-				 m_color.A});
+				 myColor.A});
 		}
 	}
 	else
 	{
 		// all points: same color
-		cbd.assign(N, m_color);
+		cbd.assign(N, myColor);
 	}
 
 	m_last_rendered_count = m_last_rendered_count_ongoing;
@@ -313,7 +315,9 @@ void CPointCloud::serializeFrom(
 			{
 				std::vector<float> xs, ys, zs;
 				in >> xs >> ys >> zs;
+				wfWriteLock.unlock();  // avoid recursive lock
 				this->setAllPoints(xs, ys, zs);
+				wfWriteLock.lock();
 			}
 			else
 			{
@@ -338,9 +342,7 @@ void CPointCloud::serializeFrom(
 			else
 			{
 				m_colorFromDepth_min = TColorf(0, 0, 0);
-				m_colorFromDepth_max.R = m_color.R * 255.f;
-				m_colorFromDepth_max.G = m_color.G * 255.f;
-				m_colorFromDepth_max.B = m_color.B * 255.f;
+				m_colorFromDepth_max = getColor();
 			}
 
 			if (version >= 4) in >> m_pointSmooth;
@@ -430,7 +432,7 @@ void CPointCloud::markAllPointsAsNew()
 
 /** In a base class, reserve memory to prepare subsequent calls to
  * PLY_import_set_vertex */
-void CPointCloud::PLY_import_set_vertex_count(const size_t N)
+void CPointCloud::PLY_import_set_vertex_count(size_t N)
 {
 	std::unique_lock<std::shared_mutex> wfWriteLock(
 		CRenderizableShaderPoints::m_pointsMtx.data);
@@ -443,7 +445,7 @@ void CPointCloud::PLY_import_set_vertex_count(const size_t N)
  * does not provide color info.
  */
 void CPointCloud::PLY_import_set_vertex(
-	const size_t idx, const mrpt::math::TPoint3Df& pt,
+	size_t idx, const mrpt::math::TPoint3Df& pt,
 	[[maybe_unused]] const mrpt::img::TColorf* pt_color)
 {
 	std::unique_lock<std::shared_mutex> wfWriteLock(
@@ -459,7 +461,7 @@ size_t CPointCloud::PLY_export_get_vertex_count() const { return this->size(); }
  * file does not provide color info.
  */
 void CPointCloud::PLY_export_get_vertex(
-	const size_t idx, mrpt::math::TPoint3Df& pt, bool& pt_has_color,
+	size_t idx, mrpt::math::TPoint3Df& pt, bool& pt_has_color,
 	[[maybe_unused]] mrpt::img::TColorf& pt_color) const
 {
 	std::shared_lock<std::shared_mutex> wfReadLock(
