@@ -18,6 +18,8 @@ using namespace mrpt::opengl;
 
 void CTextMessageCapable::TListTextMessages::regenerateGLobjects() const
 {
+	std::unique_lock<std::shared_mutex> lckWrite2DTexts(mtx.data);
+
 	// (re)generate the opengl CText objects for each label:
 	for (auto& kv : messages)
 	{
@@ -38,15 +40,21 @@ void CTextMessageCapable::TListTextMessages::regenerateGLobjects() const
 	}
 }
 
-void CTextMessageCapable::clearTextMessages() { m_2D_texts.messages.clear(); }
+void CTextMessageCapable::clearTextMessages()
+{
+	std::unique_lock<std::shared_mutex> lckWrite2DTexts(m_2D_texts.mtx.data);
+	m_2D_texts.messages.clear();
+}
 
 /** Just updates the text of a given text message, without touching the other
  * parameters.
  * \return false if given ID doesn't exist.
  */
 bool CTextMessageCapable::updateTextMessage(
-	const size_t unique_index, const std::string& text)
+	size_t unique_index, const std::string& text)
 {
+	std::unique_lock<std::shared_mutex> lckWrite2DTexts(m_2D_texts.mtx.data);
+
 	auto it = m_2D_texts.messages.find(unique_index);
 	if (it == m_2D_texts.messages.end()) return false;
 	else
@@ -61,7 +69,7 @@ bool CTextMessageCapable::updateTextMessage(
 /// mrpt::opengl::gl_utils::glDrawText()
 void CTextMessageCapable::addTextMessage(
 	const double x_frac, const double y_frac, const std::string& text,
-	const size_t unique_index, const TFontParams& fontParams)
+	size_t unique_index, const TFontParams& fontParams)
 {
 	DataPerText d;
 	static_cast<TFontParams&>(d) = fontParams;
@@ -69,5 +77,6 @@ void CTextMessageCapable::addTextMessage(
 	d.x = x_frac;
 	d.y = y_frac;
 
+	std::unique_lock<std::shared_mutex> lckWrite2DTexts(m_2D_texts.mtx.data);
 	m_2D_texts.messages[unique_index] = std::move(d);
 }
