@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2022, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2023, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -318,7 +318,7 @@ class CRandomGenerator
 		{
 			const auto s = std::sqrt(eigVals[c]);
 			for (typename COVMATRIX::Index r = 0; r < eigVecs.rows(); r++)
-				eigVecs(c, r) *= s;
+				eigVecs(r, c) *= s;
 		}
 
 		// Set size of output vector:
@@ -366,7 +366,7 @@ class CRandomGenerator
 		{
 			const auto s = std::sqrt(eigVals[c]);
 			for (typename COVMATRIX::Index r = 0; r < eigVecs.rows(); r++)
-				eigVecs(c, r) *= s;
+				eigVecs(r, c) *= s;
 		}
 
 		// Set size of output vector:
