@@ -242,7 +242,7 @@ class CMultiMetricMapPDF
 
 	// see docs in base
 	mrpt::math::TPose3D getLastPose(
-		const size_t i, bool& pose_is_valid) const override;
+		size_t i, bool& pose_is_valid) const override;
 
 	void PF_SLAM_implementation_custom_update_particle_with_new_pose(
 		CParticleDataContent* particleData,
@@ -261,8 +261,7 @@ class CMultiMetricMapPDF
 	 */
 	double PF_SLAM_computeObservationLikelihoodForParticle(
 		const mrpt::bayes::CParticleFilter::TParticleFilterOptions& PF_options,
-		const size_t particleIndexForMap,
-		const mrpt::obs::CSensoryFrame& observation,
+		size_t particleIndexForMap, const mrpt::obs::CSensoryFrame& observation,
 		const mrpt::poses::CPose3D& x) const override;
 	/** @} */
 
