@@ -9,6 +9,7 @@
 #pragma once
 
 #include <mrpt/obs/obs_frwds.h>
+#include <mrpt/opengl/CSetOfObjects.h>
 #include <mrpt/poses/CPosePDFParticles.h>
 #include <mrpt/slam/PF_implementations_data.h>
 #include <mrpt/slam/TMonteCarloLocalizationParams.h>
@@ -132,13 +133,22 @@ class CMonteCarloLocalization2D
 		const bayes::CParticleFilter::TParticleFilterOptions& PF_options)
 		override;
 
+	/** Returns a 3D representation of this PDF.
+	 * \note Needs the mrpt-opengl library, and using
+	 * mrpt::opengl::CSetOfObjects::Ptr as template argument.
+	 */
+	mrpt::opengl::CSetOfObjects::Ptr getVisualization() const
+	{
+		return mrpt::opengl::CSetOfObjects::posePDF2opengl(*this);
+	}
+
 	// protected:
 	/** \name Virtual methods that the PF_implementations assume exist.
 		@{ */
 	/** Return the robot pose for the i'th particle. is_valid is
 	 * always true in this class. */
 	mrpt::math::TPose3D getLastPose(
-		const size_t i, bool& is_valid_pose) const override;
+		size_t i, bool& is_valid_pose) const override;
 
 	void PF_SLAM_implementation_custom_update_particle_with_new_pose(
 		mrpt::math::TPose2D* particleData,
@@ -155,8 +165,7 @@ class CMonteCarloLocalization2D
 	 */
 	double PF_SLAM_computeObservationLikelihoodForParticle(
 		const mrpt::bayes::CParticleFilter::TParticleFilterOptions& PF_options,
-		const size_t particleIndexForMap,
-		const mrpt::obs::CSensoryFrame& observation,
+		size_t particleIndexForMap, const mrpt::obs::CSensoryFrame& observation,
 		const mrpt::poses::CPose3D& x) const override;
 	/** @} */
 
