@@ -23,9 +23,10 @@
 #include <mrpt/poses/CPosePDFGaussian.h>
 #include <mrpt/poses/CPosePDFGrid.h>
 #include <mrpt/random.h>
-#include <mrpt/slam/PF_aux_structs.h>
 #include <mrpt/system/CTicTac.h>
 
+#include "PF_aux_structs.h"
+
 using namespace mrpt;
 using namespace mrpt::bayes;
 using namespace mrpt::math;
@@ -940,7 +941,7 @@ bool CMultiMetricMapPDF::PF_SLAM_implementation_skipRobotMovement() const
  ---------------------------------------------------------------*/
 double CMultiMetricMapPDF::PF_SLAM_computeObservationLikelihoodForParticle(
 	[[maybe_unused]] const CParticleFilter::TParticleFilterOptions& PF_options,
-	const size_t particleIndexForMap, const CSensoryFrame& observation,
+	size_t particleIndexForMap, const CSensoryFrame& observation,
 	const CPose3D& x) const
 {
 	auto* map = const_cast<CMultiMetricMap*>(
