@@ -20,7 +20,7 @@ using namespace mrpt::system;
 
 void COccupancyGridMapFeatureExtractor::uncached_extractFeatures(
 	const mrpt::maps::COccupancyGridMap2D& grid,
-	mrpt::maps::CLandmarksMap& outMap, const size_t number_of_features,
+	mrpt::maps::CLandmarksMap& outMap, size_t number_of_features,
 	const mrpt::vision::TDescriptorType descriptors,
 	const mrpt::vision::CFeatureExtraction::TOptions& feat_options)
 {
@@ -79,7 +79,7 @@ void COccupancyGridMapFeatureExtractor::uncached_extractFeatures(
   ---------------------------------------------------------------*/
 void COccupancyGridMapFeatureExtractor::extractFeatures(
 	const mrpt::maps::COccupancyGridMap2D& grid,
-	mrpt::maps::CLandmarksMap& outMap, const size_t number_of_features,
+	mrpt::maps::CLandmarksMap& outMap, size_t number_of_features,
 	const mrpt::vision::TDescriptorType descriptors,
 	const mrpt::vision::CFeatureExtraction::TOptions& feat_options)
 {
