@@ -9,6 +9,7 @@
 #pragma once
 
 #include <cstddef>
+#include <cstdint>
 #include <string>
 #include <vector>
 
@@ -24,6 +25,6 @@ std::string md5(const std::string& str);
 /** Computes the md5 of a block of data. */
 std::string md5(const std::vector<uint8_t>& str);
 /** Computes the md5 of a block of data. */
-std::string md5(const unsigned char* data, const size_t len);
+std::string md5(const unsigned char* data, size_t len);
 /** @} */
 }  // namespace mrpt::system
