@@ -10,7 +10,7 @@
 #include <mrpt/core/exceptions.h>
 #include <mrpt/detectors.h>
 #include <mrpt/examples_config.h>
-#include <mrpt/gui.h>
+#include <mrpt/gui/CDisplayWindow3D.h>
 #include <mrpt/hwdrivers/CCameraSensor.h>
 #include <mrpt/img/TColor.h>
 #include <mrpt/maps/CColouredPointsMap.h>
@@ -76,8 +76,8 @@ void TestCamera3DFaceDetection(CCameraSensor::Ptr cam)
 	win3D.setCameraZoom(6.0);
 	win3D.setCameraPointingToPoint(2.5, 0, 0);
 
-	mrpt::opengl::COpenGLScene::Ptr& scene = win3D.get3DSceneAndLock();
-	mrpt::opengl::COpenGLScene::Ptr scene2;
+	mrpt::opengl::Scene::Ptr& scene = win3D.get3DSceneAndLock();
+	mrpt::opengl::Scene::Ptr scene2;
 
 	mrpt::opengl::CPointCloudColoured::Ptr gl_points =
 		mrpt::opengl::CPointCloudColoured::Create();
