@@ -412,7 +412,7 @@ static void AppDepthCamDemo()
 	// Add a background scene:
 	// -----------------------------
 	{
-		auto scene = mrpt::opengl::COpenGLScene::Create();
+		auto scene = mrpt::opengl::Scene::Create();
 		scene->insert(mrpt::opengl::CGridPlaneXY::Create());
 
 		scene->insert(app.gl_corner_reference);
