@@ -42,7 +42,7 @@ void TestGridMap3D()
 	auto gl_map = mrpt::opengl::COctoMapVoxels::Create();
 
 	{
-		mrpt::opengl::COpenGLScene::Ptr& scene = win.get3DSceneAndLock();
+		mrpt::opengl::Scene::Ptr& scene = win.get3DSceneAndLock();
 
 		{
 			mrpt::opengl::CGridPlaneXY::Ptr gl_grid =
