@@ -120,7 +120,7 @@ void TestRANSAC()
 	mrpt::opengl::CSetOfLines::Ptr gl_lines =
 		mrpt::opengl::CSetOfLines::Create();
 	{
-		mrpt::opengl::COpenGLScene::Ptr& scene = win.get3DSceneAndLock();
+		mrpt::opengl::Scene::Ptr& scene = win.get3DSceneAndLock();
 
 		scene->getViewport("main")->setCustomBackgroundColor(
 			TColorf(0.8f, 0.8f, 0.8f));
@@ -311,7 +311,7 @@ void TestRANSAC()
 		cout << "Ground truth pose: " << GT_pose << endl;
 
 		{
-			// mrpt::opengl::COpenGLScene::Ptr &scene =
+			// mrpt::opengl::Scene::Ptr &scene =
 			win.get3DSceneAndLock();
 
 			win.addTextMessage(
