@@ -15,7 +15,7 @@
  *
  */
 
-#include <mrpt/gui.h>
+#include <mrpt/gui/CDisplayWindow3D.h>
 #include <mrpt/opengl/CAngularObservationMesh.h>
 #include <mrpt/opengl/CAxis.h>
 #include <mrpt/opengl/CCylinder.h>
@@ -29,6 +29,7 @@
 #include <mrpt/poses/CPose3D.h>
 #include <mrpt/random.h>
 #include <mrpt/system/CTicTac.h>
+#include <mrpt/system/os.h>
 
 #include <chrono>
 #include <iostream>
@@ -156,8 +157,8 @@ void display()
 	CDisplayWindow3D window("Ray trace demo", 640, 480);
 	window.setPos(10, 10);
 	std::this_thread::sleep_for(20ms);
-	COpenGLScene::Ptr scene1 = COpenGLScene::Create();
-	// COpenGLScene::Ptr &scene1=window.get3DSceneAndLock();
+	Scene::Ptr scene1 = Scene::Create();
+	// Scene::Ptr &scene1=window.get3DSceneAndLock();
 	opengl::CGridPlaneXY::Ptr plane1 =
 		CGridPlaneXY::Create(-20, 20, -20, 20, 0, 1);
 	plane1->setColor(GRID_R, GRID_G, GRID_B);
@@ -207,7 +208,7 @@ void display()
 	window.get3DSceneAndLock() = scene1;
 	window.unlockAccess3DScene();
 	window.setCameraElevationDeg(25.0f);
-	COpenGLScene::Ptr& scene2 = window2.get3DSceneAndLock();
+	Scene::Ptr& scene2 = window2.get3DSceneAndLock();
 	scene2->insert(aom);
 	opengl::CGridPlaneXY::Ptr plane2 =
 		CGridPlaneXY::Create(-20, 20, -20, 20, 0, 1);
